"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WinixAPI = void 0;
const axios_1 = __importDefault(require("axios"));
var Attribute;
(function (Attribute) {
    Attribute["Power"] = "A02";
    Attribute["Mode"] = "A03";
    Attribute["Airflow"] = "A04";
    Attribute["Plasmawave"] = "A07";
    Attribute["AirQuality"] = "S07";
})(Attribute || (Attribute = {}));
class WinixAPI {
    async getPower(deviceId) {
        return await this.getDeviceAttribute(deviceId, Attribute.Power);
    }
    async setPower(deviceId, value) {
        return await this.setDeviceAttribute(deviceId, Attribute.Power, value);
    }
    async getMode(deviceId) {
        return await this.getDeviceAttribute(deviceId, Attribute.Mode);
    }
    async setMode(deviceId, value) {
        return await this.setDeviceAttribute(deviceId, Attribute.Mode, value);
    }
    async getAirflow(deviceId) {
        return await this.getDeviceAttribute(deviceId, Attribute.Airflow);
    }
    async setAirflow(deviceId, value) {
        return await this.setDeviceAttribute(deviceId, Attribute.Airflow, value);
    }
    async getAirQuality(deviceId) {
        return await this.getDeviceAttribute(deviceId, Attribute.AirQuality);
    }
    async getPlasmawave(deviceId) {
        return await this.getDeviceAttribute(deviceId, Attribute.Plasmawave);
    }
    async setPlasmawave(deviceId, value) {
        return await this.setDeviceAttribute(deviceId, Attribute.Plasmawave, value);
    }
    async getDeviceStatus(deviceId) {
        const attributes = await this.getDeviceStatusInternal(deviceId);
        return this.toDevice(attributes);
    }
    async getDeviceStatusInternal(deviceId) {
        const url = this.getDeviceStatusUrl(deviceId);
        const result = await axios_1.default.get(url);
        return result.data.body.data[0].attributes;
    }
    async getDeviceAttribute(deviceId, attribute) {
        const attributes = await this.getDeviceStatusInternal(deviceId);
        return attributes[attribute.toString()];
    }
    async setDeviceAttribute(deviceId, attribute, value) {
        const url = this.getSetAttributeUrl(deviceId, attribute, value);
        await axios_1.default.get(url);
        return value;
    }
    getDeviceStatusUrl(deviceId) {
        return `https://us.api.winix-iot.com/common/event/sttus/devices/${deviceId}`;
    }
    getSetAttributeUrl(deviceId, attribute, value) {
        return `https://us.api.winix-iot.com/common/control/devices/${deviceId}/A211/${attribute}:${value}`;
    }
    toDevice(attributes) {
        return {
            power: attributes[Attribute.Power],
            mode: attributes[Attribute.Mode],
            airflow: attributes[Attribute.Airflow],
            airQuality: attributes[Attribute.AirQuality],
            plasmawave: attributes[Attribute.Plasmawave],
        };
    }
}
exports.WinixAPI = WinixAPI;
